var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import EventEmitter from 'eventemitter3';
import { buildPath } from './utils';
export class Downloader extends EventEmitter {
    constructor(storage, queue, basePath = '') {
        super();
        this.storage = storage;
        this.queue = queue;
        this.basePath = basePath;
    }
    setBasePath(path) {
        this.basePath = this.basePath;
    }
    download() {
        return __awaiter(this, void 0, void 0, function* () {
            const downloaded = new Map();
            let numDownloaded = 0;
            while (this.queue.length() > 0) {
                const path = this.queue.pop();
                const item = yield this.downloadItem(buildPath(this.basePath, path));
                downloaded.set(path, item);
                numDownloaded++;
                this.emit('download.progress', {
                    downloaded: numDownloaded,
                    remaining: this.queue.length()
                });
            }
            return downloaded;
        });
    }
    downloadItem(path) {
        return __awaiter(this, void 0, void 0, function* () {
            const inCache = yield this.storage.get(path);
            if (inCache) {
                return inCache;
            }
            const response = yield fetch(path);
            this.storage.add(path, response);
            return response;
        });
    }
}
